# Stolos - Effortless development in the cloud, using your local tools

## Usage

For usage information, please visit [http://docs.stolos.io/cli/](http://docs.stolos.io/cli/)

## Installation

For installation instructions, please visit [http://docs.stolos.io/start/installing-stolos](http://docs.stolos.io/start/installing-stolos)

## Development

In order to install this library for development, use:

```bash
git clone git@github.com:sourcelair/stolosctl
pip install --editable ./stolosctl
```

## Documentation

* [Configuration overview](docs/configuration.md)
